! DESCRIP.MMS for FISH, a VMS SSH client.
!
!   Copyright (c) 1998, Christer Weinigel <wingel@ctrl-c.liu.se>
!   Copyright (c) 1998, Richard Levitte <richard@levitte.org>
!
!   See the file COPYRIGHT. for further information
!
!--------------------------------------------------------------
!
!	User macros.  Change at will.
!
! We need a few files from SSLeay.  YOU PROBABLY NEED TO CHANGE THIS!
SSLINCLUDEDIR = dev:[SSLEAY-0_8_1.INCLUDE]
SSLLIBDIR = SSLLIB:

CC = cc /decc /nowarn /debug /define=_DECC_V4_SOURCE=1
CFLAGS = /include=$(SSLINCLUDEDIR)
LDFLAGS = 

!--------------------------------------------------------------
!
!	Internal macro definitions.  Please do not change
!
LIBRARYMODULES = fish, ssh, packet, crc32, 3des, idea
LIBRARIES = fishlib.olb($(LIBRARYMODULES)) 
SOURCEDIR = [-.SRC]

! All the source we distribute
DISTFILES = *.txt copyright.* *.com [.src]*.c [.src]*.h [.src]*.mms [.src]version.opt
! Some binaries we also distribute
ZIPDISTEXTRA = [.bin-*]*.*

! include version.opt, since that gives us information like version number.
.include version.opt

!--------------------------------------------------------------
!
!	On to the building part
!
.FIRST :
	CPU := VAX
	if f$getsyi("CPU") .ge. 128 then CPU := AXP
	if f$parse("[-.BIN-''CPU']") .eqs. "" then -
		create/dir [-.BIN-'CPU']
	SSLlibrary := $(SSLLIBDIR)LIBSSLEAY.OLB
	if f$search(SSLlibrary) .eqs. "" then -
		SSLlibrary := $(SSLLIBDIR)CRYPTO-'CPU'.OLB
	if f$search(SSLlibrary) .eqs. "" then -
		SSLlibrary :=
	if SSLlibrary .eqs. "" then -
		write sys$error "I can't find the SSLeay library, what shall I do?"
	if SSLlibrary .eqs. "" then exit

all : fish.exe
	@ $

fish.exe :  $(LIBRARIES) fish.opt
	copy fishlib.olb [-.BIN-'CPU']
	- link /exec=fish.exe fishlib/lib /include=(fish),fish.opt/opt,version.opt/opt $(LDFLAGS)
	copy fish.exe [-]

fish.opt : descrip.mms
	open/write fish_opt fish.opt
	write fish_opt SSLlibrary,"/LIB"
	write fish_opt "NETLIB_SHRXFR/SHARE"
	close fish_opt

almostclean :
	- purge/log
	- delete/log *.obj;*
	- delete/log *.exe;*,[-]*.exe;*

olbclean : 
	- delete/log *.olb;*

clean :
	- delete/log [-.BIN-'CPU']*.olb;*

optclean :
	- delete/log fish.opt;*

distclean : clean optclean
	@ !

dist : almostclean optclean olbclean versions zip.comment
	copy 'SSLlibrary' [-.BIN-'CPU']
	purge [-.BIN-'CPU']
	set default [-]
	- delete fish'vmsver'.zip;*
	- define/user sys$input zip.comment
	- define/user sys$output zip.log
	- zip -"Vz" fish'vmsver'.zip $(DISTFILES) $(ZIPDISTEXTRA)

versions : version.opt FRC
	version = f$extract(1,10,$(IDENT))
	major = f$element(0,".",version)
	minor = f$element(0,"-",f$element(1,".",version))
	update = f$element(1,"-",version)
	vmsver = "0''major'''minor'"
	if major .gt. 9 then vmsver = "''major'''minor'"
	if update .nes. "-" then vmsver = "U''update'"+vmsver
	
zip.comment : version.opt descrip.mms
	- open/write foo [-]zip.comment
	- write foo ""
	- write foo "FISH ''version' -- an SSH client for VMS"
	- write foo ""
	- write foo "Runs on both OpenVMS/VAX and OpenVMS/AXP."
	- write foo ""
	- write foo "To get the executable, just do @LINK after you extracted"
	- write foo "the files."
	- write foo ""
	- close foo

FRC :
	@ ! This clause is to force other clauses to happen.

!--------------------------------------------------------------
!
!	Source dependencies
!
fish.obj : pilot.h ssh.h ui.h $(SSLINCLUDEDIR)rand.h erf.h
ssh.obj : pilot.h ssh.h $(SSLINCLUDEDIR)bn.h $(SSLINCLUDEDIR)rsa.h -
	  $(SSLINCLUDEDIR)rand.h $(SSLINCLUDEDIR)md5.h callback.h erf.h
packet.obj : pilot.h ssh.h crc32.h $(SSLINCLUDEDIR)rand.h callback.h erf.h
3des.obj : pilot.h ssh.h $(SSLINCLUDEDIR)des.h erf.h
idea.obj : pilot.h ssh.h $(SSLINCLUDEDIR)idea.h erf.h
sock.obj : pilot.h sock.h ssh.h erf.h
ui.obj : pilot.h ui.h ssh.h erf.h
